@@ -6,7 +6,7 @@ from algora.common.decorators import async_data_request
 from algora.common.requests import __async_get_request
 
 
-@async_data_request(transformer=_transform_fred_observations)
+@async_data_request(transformers=[_transform_fred_observations])
 async def async_get_series(query: FredQuery):
     """
     Asynchronously get FRED series.
