@@ -12,7 +12,7 @@ config = EnvironmentConfig()
 class FredQuery(Base):
     series_id: str
     api_key: str = Field(default=config.auth_config.fred_api_key, init=False)
-    file_type: str = Field(default='json')
+    file_type: str = Field(default="json")
     observation_start: Optional[date] = None
     observation_end: Optional[date] = None
 
