@@ -1,6 +1,6 @@
 from pandas import DataFrame
 
-from algora.api.data.iex.__utils import __base_request
+from algora.api.data.iex.__util import __base_request
 from algora.api.data.iex.energy.__util import __build_params
 from algora.common.decorators import data_request
 
@@ -8,9 +8,8 @@ from algora.common.decorators import data_request
 @data_request
 def historical_oil_prices(symbol: str, **kwargs) -> DataFrame:
     """
-    Wrapper for IEX's Historical Energy Prices via Time Series API
-
-    Reference: https://iexcloud.io/docs/api/#time-series-endpoint
+    Wrapper for IEX historical energy prices via
+    [Time Series API](https://iexcloud.io/docs/api/#time-series-endpoint).
 
     Args:
         symbol (str): "DCOILWTICO" or "DCOILBRENTEU"
