@@ -7,12 +7,16 @@ import aiohttp
 from requests import Response
 
 from algora.api.service.auth.__util import (
-    _login_request_info, _refresh_token_request_info, _token_exchange_request_info
+    _login_request_info,
+    _refresh_token_request_info,
+    _token_exchange_request_info,
 )
 from algora.common.function import build_response_obj
 
 
-async def async_login(username: str, password: str, scope: Optional[str] = None) -> Response:
+async def async_login(
+    username: str, password: str, scope: Optional[str] = None
+) -> Response:
     """
     Asynchronously login.
 
