@@ -45,7 +45,7 @@ def __partition_key_mapping(request: DataRequest) -> Tuple[date, str]:
 
 
 def build_partition_key(timestamp: int, request: DataRequest) -> str:
-    excluded_keys = {'as_of_date', 'start_date', 'end_date', 'as_of'}
+    excluded_keys = {"as_of_date", "start_date", "end_date", "as_of"}
     return f"{timestamp}.{request.base64_encoded(exclude=excluded_keys)}"
 
 
@@ -57,7 +57,7 @@ def get_key_partitions(request: DataRequest) -> Dict[date, str]:
         start = request.start_date.date()
         end = request.end_date.date()
 
-        for _date in create_dates_between(start=start, end=end, frequency='D'):
+        for _date in create_dates_between(start=start, end=end, frequency="D"):
             base_request = request.copy(deep=True)
             base_request.as_of_date = _date
             base_request.start_date = None
@@ -71,7 +71,9 @@ def partition_dataframe(df: pd.DataFrame):
     if df.empty:
         return {}
 
-    return {dt.date(): data for dt, data in df.groupby(pd.Grouper(key='date', freq='D'))}
+    return {
+        dt.date(): data for dt, data in df.groupby(pd.Grouper(key="date", freq="D"))
+    }
 
 
 day_partition_cache = partial(
@@ -80,5 +82,5 @@ day_partition_cache = partial(
     combine_partitions=pd.concat,
     partition_value=partition_dataframe,
     cache_lookup_criterion=lambda key: key.as_of_date is not None,
-    key=__get_request
+    key=__get_request,
 )
