@@ -10,14 +10,14 @@ from requests import Response
 from algora.api.service.auth import login, refresh_token as refresh_token_request
 from algora.common.config import EnvironmentConfig
 from algora.common.decorators.authorization.__util import (
-    _access_token, _handle_auth_response, _validate_headers
+    _access_token,
+    _handle_auth_response,
+    _validate_headers,
 )
 
 
 def authenticated_request(
-        request: Callable = None,
-        *,
-        env_config: Optional[EnvironmentConfig] = None
+    request: Callable = None, *, env_config: Optional[EnvironmentConfig] = None
 ) -> Callable:
     """
     Decorator for requests that need to be authenticated
@@ -51,9 +51,11 @@ def authenticated_request(
                     username=config.auth_config.username,
                     password=config.auth_config.password,
                     access_token=config.auth_config.access_token,
-                    refresh_token=config.auth_config.refresh_token
+                    refresh_token=config.auth_config.refresh_token,
                 )
-                auth_headers.update(headers)  # override authentication header if already provided
+                auth_headers.update(
+                    headers
+                )  # override authentication header if already provided
                 kwargs["headers"] = auth_headers
 
             return _make_request(f, config, *args, **kwargs)
@@ -68,10 +70,10 @@ def authenticated_request(
 # TODO: Figure out max size
 @cached(cache=TTLCache(maxsize=100, ttl=1740))
 def _authenticate(
-        username: Optional[str],
-        password: Optional[str],
-        access_token: Optional[str],
-        refresh_token: Optional[str]
+    username: Optional[str],
+    password: Optional[str],
+    access_token: Optional[str],
+    refresh_token: Optional[str],
 ) -> dict:
     """
     Authenticate user and create user authentication headers.
@@ -87,10 +89,7 @@ def _authenticate(
     """
     auth_headers = {}
     if username and password:
-        auth_headers = _sign_in(
-            username=username,
-            password=password
-        )
+        auth_headers = _sign_in(username=username, password=password)
     elif access_token:
         auth_headers = _access_token(access_token)
     elif refresh_token:
@@ -105,16 +104,20 @@ def _sign_in(username: str, password: str) -> dict:
 
 def _refresh_token(refresh_token: Optional[str] = None) -> dict:
     auth_response = refresh_token_request(refresh_token)
-    return _handle_auth_response(auth_response, error_msg="Failed to refresh the user's token")
+    return _handle_auth_response(
+        auth_response, error_msg="Failed to refresh the user's token"
+    )
 
 
-def _make_request(func: Callable, config: EnvironmentConfig, *args, **kwargs) -> Response:
+def _make_request(
+    func: Callable, config: EnvironmentConfig, *args, **kwargs
+) -> Response:
     _validate_headers(**kwargs)
 
     response: Response = func(*args, **kwargs)
     if response.status_code == 401 and config.auth_config.refresh_token:
         auth_headers = _refresh_token(config.auth_config.refresh_token)
-        kwargs['headers'].update(auth_headers)  # override authentication header
+        kwargs["headers"].update(auth_headers)  # override authentication header
         response: Response = func(*args, **kwargs)
 
     return response
