@@ -1,5 +1,5 @@
 def init_subclass(cls):
-    cls._subtypes_[cls.__name__.lower()] = cls
+    cls._subtypes_[cls.__name__] = cls
 
 
 def parse_obj(cls, obj):
